Generate random example data for testing TorchDecon functionality. Creates a simple Seurat object and bulk expression data.
Usage
GenerateExampleData(
n_cells = 500L,
n_genes = 200L,
n_celltypes = 5L,
n_bulk_samples = 20L,
seed = 42L
)Generate random example data for testing TorchDecon functionality. Creates a simple Seurat object and bulk expression data.
GenerateExampleData(
n_cells = 500L,
n_genes = 200L,
n_celltypes = 5L,
n_bulk_samples = 20L,
seed = 42L
)